#!/bin/sh

#
# Check if one ID from current firmware whitelist file is included
#       in firmware update compatibility identifier file
# TODO: file names hard coded here or as arguments ?
#


#
# File names.
#
# FQFN to firmware update compatibility identifier list in current firmware.
CUR_FILE=/etc/Counter/update_compatibility_whitelist.txt
# File name of firmware update packet compatibility identifier file.
UPD_FILE=update_file_compatibility_data.txt
# The update log file FQFN.
UPDATE_LOGFILE=/var/log/update.log

#
# Exit code definition.
#
EXIT_MATCH_FOUND=0      # compatibility (ID match found)
EXIT_ERR_NO_MATCH=1     # no compatibility (no ID match found)
EXIT_CUR_FILE_MISSED=2  # current firmware whitelist file not available
EXIT_UPD_FILE_MISSED=3  # firmware update packet compatibility identifier file not available


#
# Script file name.
#
SCRIPT_NAME=$(basename $0)


#
# Check if files are available.
#
test -f ${CUR_FILE} || {
    LOG_STR="Firmware update compatibility whitelist file not found: ${CUR_FILE}."
    logger -p error -t ${SCRIPT_NAME} "${LOG_STR}"
    echo "$(date): ${SCRIPT_NAME}: Error: ${LOG_STR}" >>${UPDATE_LOGFILE}
    exit ${EXIT_CUR_FILE_MISSED}
}
test -f ${UPD_FILE} || {
    LOG_STR="Firmware update packet compatibility identifier file not found: ${UPD_FILE}."
    logger -p error -t ${SCRIPT_NAME} "${LOG_STR}"
    echo "$(date): ${SCRIPT_NAME}: Error: ${LOG_STR}" >>${UPDATE_LOGFILE}
    exit ${EXIT_UPD_FILE_MISSED}
}


#
# Check if an ID from firmware whitelist file is included in 
#       firmware update packet compatibility identifier file.
#
# Loop IDs (lines) in firmware whitelist file.
while read LINE_CUR ; do
    # Get ID from current line firmware update compatibility whitelist file.
    ID_CUR=`echo $LINE_CUR | /usr/bin/awk -F \; ' { print $1 }'`
    # Loop IDs (lines) in firmware update packet compatibility identifier file.
    while read LINE_UPD ; do
        # Get ID from current line in firmware update packet compatibility identifier file.
        ID_UPD=`echo $LINE_UPD | /usr/bin/awk -F \; ' { print $1 }'`
        # Check for ID match, if match found exit with "match found".
        if [ $ID_CUR -eq $ID_UPD ] ; then
            LOG_STR="Firmware update packet is compatible with current firmware (match found for ID = ${ID_CUR})."
            logger -p notice -t ${SCRIPT_NAME} "${LOG_STR}"
            echo "$(date): ${SCRIPT_NAME}: Notice: ${LOG_STR}" >>${UPDATE_LOGFILE}
            exit ${EXIT_MATCH_FOUND}
        fi
    done < "${UPD_FILE}"
done < "${CUR_FILE}"


#
# No match found if we are here.
#
LOG_STR="Firmware update compatibility check failed (no match found)."
logger -p error -t ${SCRIPT_NAME} "${LOG_STR}"
echo "$(date): ${SCRIPT_NAME}: Error: ${LOG_STR}" >>${UPDATE_LOGFILE}
exit ${EXIT_ERR_NO_MATCH}
